(function ($) {
  "user strict";
  // Preloader Js
  $(window).on("load", function () {
    $(".preloader").fadeOut(1000);
    var img = $(".bg_img");
    img.css("background-image", function () {
      var bg = "url(" + $(this).data("background") + ")";
      return bg;
    });

    // var otherImg = $(".bg_img_carousel");
    // var images = otherImg.data("backgrounds");

    // var counter = 0;
    // var interval = setInterval(function () {
    //   otherImg.fadeOut(1000, function () {
    //     console.log(counter);
    //     counter = (counter + 1) % images.length;
    //     otherImg
    //       .css("background-image", "url(" + images[counter] + ")")
    //       .fadeIn(1000);
    //   });
    // }, 5000);

    $(window).on("beforeunload", function () {
      clearInterval(interval);
    });
  });
  $(document).ready(function () {
    //Menu Dropdown Icon Adding
    $("ul>li>.submenu").parent("li").addClass("menu-item-has-children");
    // drop down menu width overflow problem fix
    $("ul")
      .parent("li")
      .hover(function () {
        var menu = $(this).find("ul");
        var menupos = $(menu).offset();
        if (menupos.left + menu.width() > $(window).width()) {
          var newpos = -$(menu).width();
          menu.css({
            left: newpos,
          });
        }
      });
    $(".menu li a").on("click", function (e) {
      var element = $(this).parent("li");
      if (element.hasClass("open")) {
        element.removeClass("open");
        element.find("li").removeClass("open");
        element.find("ul").slideUp(300, "swing");
      } else {
        element.addClass("open");
        element.children("ul").slideDown(300, "swing");
        element.siblings("li").children("ul").slideUp(300, "swing");
        element.siblings("li").removeClass("open");
        element.siblings("li").find("li").removeClass("open");
        element.siblings("li").find("ul").slideUp(300, "swing");
      }
    });
    //Odometer
    $(".counter-item").each(function () {
      $(this).isInViewport(function (status) {
        if (status === "entered") {
          for (
            var i = 0;
            i < document.querySelectorAll(".odometer").length;
            i++
          ) {
            var el = document.querySelectorAll(".odometer")[i];
            el.innerHTML = el.getAttribute("data-odometer-final");
          }
        }
      });
    });
    new WOW().init();
    // Scroll To Top
    var scrollTop = $(".scrollToTop");
    $(window).on("scroll", function () {
      if ($(this).scrollTop() < 500) {
        scrollTop.removeClass("active");
      } else {
        scrollTop.addClass("active");
      }
    });
    //header
    var header = $("header");
    $(window).on("scroll", function () {
      if ($(this).scrollTop() < 1) {
        header.removeClass("active");
        $(".header-bottom").removeClass("active");
      } else {
        header.addClass("active");
        $(".header-bottom").addClass("active");
      }
    });
    //Click event to scroll to top
    $(".scrollToTop").on("click", function () {
      $("html, body").animate(
        {
          scrollTop: 0,
        },
        500
      );
      return false;
    });
    //Header Bar
    $(".header-bar").on("click", function () {
      $(this).toggleClass("active");
      $(".overlay").toggleClass("active");
      $(".menu").toggleClass("active");
    });
    $(".overlay").on("click", function () {
      $(".header-bar").removeClass("active");
      $(".overlay").removeClass("active");
      $(".menu").removeClass("active");
    });
    // PoPuP
    $(".popup").magnificPopup({
      disableOn: 700,
      type: "iframe",
      mainClass: "mfp-fade",
      removalDelay: 160,
      preloader: false,
      fixedContentPos: false,
      disableOn: 300,
    });
    $("body").each(function () {
      $(this)
        .find(".img-pop")
        .magnificPopup({
          type: "image",
          gallery: {
            enabled: true,
          },
        });
    });
    //Tab Section
    $(".tab ul.tab-menu")
      .addClass("active")
      .find("> li:eq(0)")
      .addClass("active");
    $(".tab ul.tab-menu li").on("click", function (g) {
      var tab = $(this).closest(".tab"),
        index = $(this).closest("li").index();
      tab.find("li").siblings("li").removeClass("active");
      $(this).closest("li").addClass("active");
      tab
        .find(".tab-area")
        .find("div.tab-item")
        .not("div.tab-item:eq(" + index + ")")
        .hide();
      tab
        .find(".tab-area")
        .find("div.tab-item:eq(" + index + ")")
        .show();
      g.preventDefault();
    });
    $(".payment-slider").owlCarousel({
      loop: true,
      nav: false,
      dots: false,
      items: 1,
      autoplay: true,
      autoHeight: true,
      margin: 30,
      responsive: {
        500: {
          items: 2,
        },
        768: {
          items: 3,
        },
        992: {
          items: 4,
        },
      },
    });
    $(".client-slider").owlCarousel({
      loop: true,
      nav: false,
      dots: false,
      items: 1,
      autoplay: true,
      margin: 30,
      responsive: {
        500: {
          items: 2,
        },
        768: {
          items: 2,
        },
      },
    });
    $(".faq-wrapper .faq-title").on("click", function (e) {
      var element = $(this).parent(".faq-item");
      if (element.hasClass("open")) {
        element.removeClass("open");
        element.find(".faq-content").removeClass("open");
        element.find(".faq-content").slideUp(200, "swing");
      } else {
        element.addClass("open");
        element.children(".faq-content").slideDown(200, "swing");
        element
          .siblings(".faq-item")
          .children(".faq-content")
          .slideUp(200, "swing");
        element.siblings(".faq-item").removeClass("open");
        element.siblings(".faq-item").find(".faq-title").removeClass("open");
        element
          .siblings(".faq-item")
          .find(".faq-content")
          .slideUp(200, "swing");
      }
    });
    $(".select-bar").niceSelect();
  });
})(jQuery);
